Boleto bancário

| 399-9 | Recibo do Sacado

Cedente | Agência/Código Cedente 0141-4/5000252 | CPF/CNPJ Cedente | Vencimento 06/11/2010
Sacado - CPF/CNPJ: | Nosso Número 1716057195 | N. do documento 1716057195 | Data Documento 06/11/2010
Endereço Cedente - - - - | Valor Documento 335,85

Demonstrativo
Autenticação Mecânica

| 399-9 | 39991.71600 57195.001417 50002.520018 1 47780000033585

Local de pagamento Pagável em qualquer banco até o vencimento | Vencimento 06/11/2010
Cedente | Agência/Código cedente 0141-4/5000252
Data do documento 06/11/2010 | N. do documento 1716057195 | Espécie doc PD | Aceite N | Data processamento 06/11/2010 | Nosso número 1716057195
Uso do banco | Carteira CSB | Espécie R$ | Quantidade | Valor | (=) Valor documento 335,85
Instruções (Todas as informações deste bloqueto são de exclusiva responsabilidade do cedente) | (-) Descontos/Abatimentos
(-) Outras deduções
(+) Mora/Multa
(+) Outros acréscimos
(=) Valor cobrado

Sacado | - CPF/CNPJ: - - -
Sacador / Avalista | Código de baixa
| Autenticação Mecânica / Ficha de Compensação